==> shiira_src1.1.zip: shiira1.1/Shiira/source/ui/SRTBIImageFrameStyleCell.h <==
/*
  SRTBIImageFrameStyleCell.h
Author: Hetima Computer

Copyright 2004 The Shiira Project. All rights reserved.

Redistribution and use in source and binary forms, with or without modification, are permitted 
provided that the following conditions are met:

  1. Redistributions of source code must retain the above copyright notice, this list of conditions 
  and the following disclaimer.

  2. Redistributions in binary form must reproduce the above copyright notice, this list of 
  conditions and the following disclaimer in the documentation and/or other materials provided 
  with the distribution.

THIS SOFTWARE IS PROVIDED BY THE SHIIRA PROJECT ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, 
INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR 
PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE SHIIRA PROJECT OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, 
INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, 
PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) 
HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING 
NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
POSSIBILITY OF SUCH DAMAGE.
*/
/*
ChangeLog
2004.04.26 Hetima Computer <>


*/

#import <Cocoa/Cocoa.h>
#import <WebKit/WebKit.h>
#import "SRError.h"
#import "HTSRTabBarView.h"

@interface SRTBIImageFrameStyleCell : HTSRTabBarItemCell <HTSRTabBarItemCellProtocol>
{
	NSSize   _stringSize;
//	int		_trackingMode;
//	BOOL	_trackingHilite;
//	NSPoint _trackingStartPoint;
}

+(float)cellHeight;
+(float)cellTopMargin;
+(float)cellBottomMargin;
+(float)displayWidthOfString:(NSString*)label;
-(id)initWithKeeperView:(id)keeperView contentView:(id)webView;

-(float)stringWidth;


-(NSImage*)dragImageForRect:(NSRect)cellFrame;
-(void)_drawLabelInRect:(NSRect)aRect;
//- (BOOL)myTrackMouse:(NSEvent *)theEvent inRect:(NSRect)cellFrame ofView:(HTSRTabBarView *)controlView point:(NSPoint)mousePt;
-(NSRect)closeBtnRectForFrame:(NSRect)cellFrame;
@end

==> shiira_src1.2.1.zip: shiira1.2.1/Shiira/source/ui/SRTBIImageFrameStyleCell.h <==
/*
  SRTBIImageFrameStyleCell.h
Author: Hetima Computer

Copyright 2004 The Shiira Project. All rights reserved.

Redistribution and use in source and binary forms, with or without modification, are permitted 
provided that the following conditions are met:

  1. Redistributions of source code must retain the above copyright notice, this list of conditions 
  and the following disclaimer.

  2. Redistributions in binary form must reproduce the above copyright notice, this list of 
  conditions and the following disclaimer in the documentation and/or other materials provided 
  with the distribution.

THIS SOFTWARE IS PROVIDED BY THE SHIIRA PROJECT ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, 
INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR 
PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE SHIIRA PROJECT OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, 
INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, 
PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) 
HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING 
NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
POSSIBILITY OF SUCH DAMAGE.
*/
/*
ChangeLog
2004.04.26 Hetima Computer <>


*/

#import <Cocoa/Cocoa.h>
#import <WebKit/WebKit.h>
#import "SRError.h"
#import "HTSRTabBarView.h"

@interface SRTBIImageFrameStyleCell : HTSRTabBarItemCell <HTSRTabBarItemCellProtocol>
{
	NSSize   _stringSize;
//	int		_trackingMode;
//	BOOL	_trackingHilite;
//	NSPoint _trackingStartPoint;
}

+(float)cellHeight;
+(float)cellTopMargin;
+(float)cellBottomMargin;
+(float)displayWidthOfString:(NSString*)label withCloseButton:(BOOL)flag;
-(id)initWithKeeperView:(id)keeperView contentView:(id)webView;

-(float)stringWidth;


-(NSImage*)dragImageForRect:(NSRect)cellFrame;
-(void)_drawLabelInRect:(NSRect)aRect offScreen:(BOOL)flag;
//- (BOOL)myTrackMouse:(NSEvent *)theEvent inRect:(NSRect)cellFrame ofView:(HTSRTabBarView *)controlView point:(NSPoint)mousePt;
-(NSRect)closeBtnRectForFrame:(NSRect)cellFrame;
@end
